@@ -24,13 +24,17 @@
 
 #include "rvln.h"
 
+#ifndef Q_OS_OS2
 #include "single_application.h"
-
+#endif
 
 int main (int argc, char *argv[])
 {
 // Q_INIT_RESOURCE (rlvn);
-/*
+   
+   
+#if defined(Q_OS_OS2)
+
   CApplication app (argc, argv);
   qApp->setApplicationName ("TEA");
   
@@ -40,17 +44,12 @@ int main (int argc, char *argv[])
 
   return app.exec();
   
-  */
-
+#else
+  
   //Q_INIT_RESOURCE (rlvn);
   
- // qDebug() << "1";
-  
   SingleApplication app (argc, argv, "tea unique id 1977");
   
- // qDebug() << "2";
-  
-  
   if (app.isRunning())
      {
        
@@ -61,23 +60,15 @@ int main (int argc, char *argv[])
        return 0;
      }
   
- // qDebug() << "3";
-  
   
   rvln *mainWindow = new rvln();
 
- // qDebug() << "4";
-  
-  
   QObject::connect(&app, SIGNAL(messageAvailable(QString)), mainWindow, SLOT(receiveMessage(QString)));
-
- // qDebug() << "5";
-  
   
   mainWindow->show();
 
- // qDebug() << "6";
-  
   
   return app.exec();   
+  
+#endif  
 }
