@@ -7,6 +7,8 @@
  * 
  */
 
+#ifndef Q_OS_OS2
+
 #ifndef SINGLE_APPLICATION_H
 #define SINGLE_APPLICATION_H
 
@@ -37,4 +39,6 @@ private:
 
         static const int timeout = 1000;
 };
-#endif // SINGLE_APPLICATION_H
\ No newline at end of file
+#endif // SINGLE_APPLICATION_H
+
+#endif //Q_OS_OS2
\ No newline at end of file
