@@ -1693,11 +1693,6 @@ Pour utiliser des penses-bêtes horodatés, spécifiez l&apos;heure au format 24
         <source>Plugins</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>It seems that %1 contains TEA plugin
-Do you want to install it?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>There is no plugin file</source>
         <translation type="unfinished"></translation>
@@ -1710,5 +1705,30 @@ Do you want to install it?</source>
         <source>put your notes (for this file) here and they will be saved automatically</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>From cursor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>not found!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>TEA program icon</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Alt key to access main menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It seems that %1 contains TEA plugin.
+ Do you want to install it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Charset for file open from command line</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
